# Changelog

All notable changes to this project will be documented in this file.

## [1.1.1] - 2023-06-06

### Added

- Prints in demos and fixed a minor bug in demo.py.

## [1.0.0] - 2025-05-29

### Added
- Public release of the version used in the paper [_**XGBOrdinal: An XGBoost Extension for Ordinal Data**_](https://doi.org/10.3233/shti250380).
- Documentation and usage examples in `README.md`.